bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 27. Aventiure
___________________________________________________ #### <Von Rudigers>
| ### o gie der marchgraue da er die vrovwen vant ### sin wip mit siner tohter vn– seite in zehant ### div lieben mere div er hete vernomen ### daz in ir vrovwen bruedere da ce hvse solten komen
###### 1591 | ### Vil liebiv trivttinne sprach do Ruediger ### ir svlt vil wol enpfahen die edelen kvnige her ### so si mit ir gesinde her ze hove gan ### ir svlt ovch schoene gruezen Hagenen Gvnthers man
###### 1592 | ### Mit in kvmet ovch einer der haizet Dancwart ### der ander heizet Volker an zvhten wol bewart ### die sehse svlt ir kvssen vnd div tohter min ### vnd svlt ovch bi den reken in zvhten guetlichen sin
###### 1593 | ### Daz lobeten do die vrowen vn– waren sin bereit ### si svohten vz den kisten div herlichen kleit ### darinne si begegene den reken wolden gan ### da wart vil michel flizen von schoenen wiben getan
###### 1594 | ### Gevelschet vrovwen varwe wie lucel man da vant ### si trvogen vf ir hovbten von golde <liehtiv> bant ### daz waren schapel riche daz in ir schoene har ### cerfuorten niht die winde si warn hvbsch vn– clar
###### 1595 | ### <In> solhen vnmvozen svl wir die vrowen lan ### hie wart vil michel gahen vber velt getan [65a] ### von Ruedigeres vriunden da man die fursten vant ### si wurden wol enphangen in des marcgrauen lant
###### 1596 | ### Do si der marcgraue zuo im komen sach ### ce sinen lieben gesten vrolichen er do sprach ### sit willekomen ir herren vn– al iwer man ### hie in mime lande vil gerne ich ivch gesach
###### 1597 | ### Do nigem im die reken mit triwen ane haz ### daz er irn willich were wol erzeiget er daz ### besvnder gruozter Hagenen den het er e bechant ### sam tet er Volkeren vzer Burgonden lant
###### 1598 | ### Er enphie ovch Dancwarten do sprach der kuene degen ### sit ir uns welt beruochen wer sol danne plegen ### des vnseres ingesindes daz wir haben braht ### do sprach der marchgraue ir svlt haben guote naht
###### 1599 | ### Spannet uf ir knehte die hutten an daz velt ### swaz ir hie verlieset des wil ich wesen gelt ### ziehet abe die zovme div ros lazzet gan ### daz het in wirt deheiner da vor uil selten getan
###### 1600 | ### Des freuten sich die geste do daz geschafet was ### die herren riten dannen sich leiten in daz gras ### vber al die knehte si heten guot gemach ### ich wen in an <der> verte nie so samfte gesach
###### 1601 | ### Div edel marchgrauinne fur div burch was gegan ### mit ir schonen tohter do sach man bi ir stan ### minnecliche vrowen vn– manich schoene meit ### die truogen vil der bovge vn– herlichiv kleit
###### 1602 | ### Daz edel gesteine luhte verre dan ### vz ir vil richen wete si waren wolgetan ### do komen ovch die geste vn– erbeizten sa zehant ### hey waz man grozer zuhte an den von Burgonden vant
###### 1603 | ### Sex vn– drizech meide vn– ander manich wip ### den was wol ze wunsche geschafen der lip ### die giengen in enkegene mit manigem kuenen man ### da wart schoene gruezen von edelen wiben getan
###### 1604 | ### Diu iunge marchgrauinne kuste die kunige alle dri ### alsam tet ir muoter da stuont Hagne bi ### ir vater hiez in kussen do blicte si in an ### er duhte si so vorhtlich daz si ez vil gerne hete lan
###### 1605 | ### Doch mvoste si da leisten daz ir der wirt gebot ### gemischet wart ir varwe si wart bleich vn– rot ### si kuste ovch Dancwarten danach den spilman ### durch sines libes ellen wart in daz gruezen getan
###### 1606 | ### Div iunge marchgrauinne nam bi der hant ### Gyselheren den iungen von Burgonden lant ### alsam tet ir mvoter Gvntheren den kuenen man ### si giengen mit den helden vil harte vrolichen dan
###### 1607 | ### Der wirt gie bi Gernote in einen witen sal ### riter vn– frovwen gesazen da zetal ### do hiez man balde schenken den gesten gvoten win ### ia endorften nimmer helde baz gehandelt sin [65b]
###### 1608 | ### Mit lieben ovgen blichen wart gesehen <an> ### Ruedegers tohter div was so wolgetan ### ia trutes in den sinnen vil manich riter gvot ### daz kvnd ovch si verdienen si was uil hohe gemuot
###### 1609 | ### Si gedahten swes si wolten des moht ab niht geschehen ### hin vn– her wider wart da uil gesehen ### an meide vn– an vrowen der saz da genuoch ### der edel videlere dem wirte holden willen truoch
###### 1610 | ### Nach gewonheite so schieden si sich da ### rittere vn– vroewen die giengen anderswa ### do rihte man die tische in dem sale wit ### den vnkvnden gesten man diende herlichen sit
###### 1611 | ### Durch der geste liebe hin ce tische gie ### div edel marchgrauinne ir tohter si do lie ### beliben bi den kinden da si von rehte saz ### die geste ir niht sahen si mvote werlichen daz
###### 1612 | ### Do si getrunken heten vn– gezzen vber al ### do wisete man die kuenen wider in den sal ### gemehelicher spruche wart da niht verdeit ### der reite vil do Volker ein degen kuene vn– gemeit
###### 1613 | ### Do sprach offenlichen der selbe spilman ### vil richer marchgraue got hat an iv getan ### vil genedichlichen wan er iv hat e eben ### ein wip so rehte schoene darzvo ein wunnichehlichez leben
###### 1614 | ### Ob ich ein furste were sprach der degen san ### vn– solde tragen krone ce wibe wolde ich han ### iwer schoene tohter des wnschet mir der mvot ### div ist minnechliche ce sehene darzvo edel vn– gvot
###### 1615 | ### Des antwurte Gernot der wol gezogene man ### vn– sold ich truttinne nach minem willen han ### so wold ich solhes wibes immer wesen vro ### des antwurte Hagne harte zuchtichlichen do
###### 1616 | ### Nv sol min herre Gyselher nemen doch ein wip ### er ist so hoher mage der marchgrauinne lip ### daz wir gerne dienden ich vn– sine man ### vn– solde si vnder krone da ze den Burgonden gan
###### 1617 | ### Div rede Ruedigeren duhte harte gvot ### vn– ovch Gotelinde ia vreute si in den mvot ### sid truogen an die helde daz si ce wibe nam ### Gyselher der edele als ez kvnige wol gezam
###### 1618 | ### Swaz sich sol fuegen wer mach daz vndersten ### man bat die iunchvrawen hin ce hove gen ### do swuor man im ze wibe daz wunnechliche wip ### dobte ovch er ze minnen ir vil minneclichen lip
###### 1619 | ### Man beschiet der iunchvrowen burge vn– lant ### des sicherte da mit eiden des edelen kvniges hant ### vn– der herre Gernot daz wurde daz getan ### do sprach der marchgraue sid ich der burge niht enhan
###### 1620 | ### so sol ich iv mit triwen immer wesen holt ### ich gibe zvo miner tohter silber vn– golt [66a] ### so hundert sovmere meist mvgen tragen ### daz ez den helden nach eren mvge wol behagen
###### 1621 | ### Do hiez man si beide sten an einen rinch ### nach gewoneheit vil manich iungelinch ### in vroelichem mvote ir zegagene stvont ### si gedahten in ir sinnen so noch die tumben gerne tvont
###### 1622 | ### Do man begvnde vragen die minnecliche meit ### ob si den reken wolde ein teil was ez ir leit ### doch dahte si ce nemene den wætlichen man ### si schamte sich der vrage so manich meit hat getan
###### 1623 | ### Ir riet ir uater Ruediger daz si spreche ia ### vn– daz si in gerne næme vil schiere do was da ### mit sinen wizen handen der si vmbesloz ### Gyselher der iunge swie lucel si sin doch genoz
###### 1624 | ### Do sprach der marchgraue ir edeln kvnige rich ### als ir nv vider ritet daz ist gewonlich ### heim ce Burgonden so gib ich iv min kint ### daz ir si mit iv fueret daz gelobeten si sint
###### 1625 | ### Swaz man da schalles horte den mvosen si doch lan ### man hiez die iunchvrowen ce kemenaten gan ### vn– ovch die geste slafen mit rvowe an den tac ### do bereite man die spise der wirt ir guotlich plach
###### 1626 | ### Do si enbizen waren si wolden dannen varn ### gen der Hvnen lande daz hiez ich wol bewaren ### sprach der wirt edele ir svlt noch hie bestan ### wan ich so lieber geste selten iht gewnnen han
###### 1627 | ### Des <antwurte> Dancwart des mach niht gesin ### wa nemet ir die spise daz brot vnd ovch den win ### daz ir so manigen reken noch <heint> mvozet han ### do daz der wirt erhorte er sprach ir svlt die rede lan
###### 1628 | ### Mine vil lieben heren ir svlt mir niht uersagen ### ia gib ich iv diespise ce viercehen tagen ### mit allem dem gesinde daz mit iv her ist komen ### mir hat der kvnich Ezel noch vil wenich iht genomen
###### 1629 | ### Swie sere si sich werten si mvosen da bestan ### vnz an den vierden morgen do wart da getan ### von des wirtes rnilte daz verre wart geseit ### er gap sinen gesten beidiv ros vn– kleit
###### 1630 | ### Ez kvnde ganger niht gewern si mvosen dannen varn ### Rvedeger der kuone kvnde wenich iht gesparn ### vor siner milte swes iemen gerte nemen ### daz verseiter niemen ez mvos in allen wol gezemen
###### 1631 | ### Ir edel ingesinde <brahte> fur daz tor ### gesatelt vil der moere do kom zvo in da vor ### vil vremder reken si truogen schilde enhant ### wan si wolden riten in daz Ezelen lant
###### 1632 | ### Der wirt do sine gabe bot vber al ### ê die edelen geste koemen fur den sal ### er kvnde miltlichen mit grozen eren leben ### sine tohter schoene het er Gyselher gegeben [66b]
###### 1633 | ### Do gab er Gernote ein wafen gvot genvoch ### daz er sit in sturmen vil herlichen truoch ### der gabe im wolde des marcgrauen wip ### doch verlos Ruediger da von sider den lip
###### 1634 | ### Do gab er Gunther dem helde lobelich ### wol truoch mit eren der edel kunich rich ### swie selten er gabe enphienge ein wafenlich gewant ### da nach neic Gunther des edelen Rvodigers hant
###### 1635 | ### Gotlint bot Hagnen als ir wol gezam ### ir minnecliche gabe sit si der kunich nam ### daz er ane ir stivre zvo der hochgezit ### von ir niht uaren solde doch widerreite er ez sit
###### 1636 | ### Allez des ich ie gesach sprach do Hagne ### so en gerte ich innen mere niht ze tragene ### niwan ienes schildes dort an iener want ### den wolde ich gerne fueren in Ezelen lant
###### 1637 | ### Do div marcgrauinne Hagnen rede vernam ### ez mande si ir leide weinens si gezam ### do dahte si vil tivre an Nuodunges tot ### den het erslagen Wittege da von het si iamers not
###### 1638 | ### Si sprach zuo dem degne den schilt wil ich iv geben ### daz wolde got von himele daz er noch solde leben ### der in da truoch en ende der lac in sturme tot ### den mvoz ich immer weinen des gat mir armer not
###### 1639 | ### Div edel marchgrauinne von dem sedele gie ### mit ir uil wizen handen si den sshilt gevie ### iv vrowe truoch in Hagnen er nam in an die hant ### iv gabe was mit eren an den reken gewant
###### 1640 | ### in hulft von liehtem pfelle obe siner varwe lac ### ezzeren schilt deheinen beluhte nie der tac ### von edelem gesteine der sin hete gegert ### ce kovfen an der koste was er wol tusent marche wer
###### 1641 | ### Den schilt hiez do Hagne von im tragen dan ### do begvnde Dancwart hin ze hove gan ### dem gap vil richiv cleider des marcgrauen chint ### div truoch er da zen Hvnen vil vrolichen sint
###### 1642 | ### Allez daz der gabe von in wart genomen ### in ir deheines hende wer ir niht bechomen ### wan durch des wirtes liebe derz in so schone bot ### sid wurden si im so vient daz si in slahen mvosten tot
###### 1643 | ### Volker der vil snelle mit siner videlen dan ### gie gezogenlichen fur Gottelinde stan ### er videlte sveze doene vnde sanch ir siniv liet ### da mit nam er urlop da er von Beclaren schiet
###### 1644 | ### Ir hiez div marchgravinne ein ladetragen ### von vriuntelicher gabe mvget ir horen sagen ### dar vz nam si zwelf povge vn– spien irns an die <h> ### die sult ir hinnen fueren in daz Ezelen lant
###### 1645 | ### vnd sult durch minen willen si ze hove tragen ### swem ir wider wendet daz man mir mvge sagen [67a] ### wie ir mir habet gedienet da ze der hochcit ### des div vrovwe gerte vil wol leistete er daz sit
###### 1646 | ### Do sprach der wirt zen gesten ir svlt dester samfter varn ### ich wil iuch selbe leiten vn– heizen wol bewaren ### daz in vf der straze niemen mvge schaden ### do wurden sine sovme harte schiere geladen
###### 1647 | ### Der wirt wart wol bereitet mit funf hundert man ### mit rossen vnd mit kleideren die fuort er mit im dan ### vil harte frolichen zvo der hochgezit ### der einer mit dem libe kom nie ce Beclaren sit
###### 1648 | ### Mit kusse minneclichen der wirt do dannen schiet ### also tet ovch Gyselher als im sin tvgen riet ### mit vmbeslozen armen si trivten schoeniv wip ### daz mvoste sit beweinen vil maniger iunchvrovwen lip
###### 1649 | ### Do wurden allenthalben die venster vf getan ### der wirt mit sinen mannen ze rossen wolde gan ### ich wan ir herze in seite div lkrefteclichen leit ### da weinde manich vrovwe vn– manich wetlichiv meit
###### 1650 | ### Nach ir lieben frivnden genvege heten ser ### die si ce Bechelaren gesahen nimmer mer ### doch riten si mit vrevden nider vber sant ### zetal bi Tvonovwe in daz Hvnische lant
###### 1651 | ### Do sprach ce den Bvrgonden der riter vil gemeit ### Ruedeger der edele ia svlen wir niht verdeit ### wesen vnser mere daz wir ce den Hvnen komen ### im hat der kvnich Ezel nie so liebes niht vernomen
###### 1652 | ### Zetal durch Osteriche der bote balde reit ### den luten allenthalben wart daz wol geseit ### daz hie helde koemen von Wurmez vber Rin ### des kvniges ingesinde kvnd ez niht leider gesin
###### 1653 | ### Die boten fur strichen mit den meren ### daz die Niblvnge ze den Hvnen weren ### dv solt si wol enphahen Kriemhilt vrovwe min ### dir koment nach grozen eren die vil lieben brueder din
###### 1654 | ### Kriemhilt div vrovwe in einem venster stvont ### si warte nach den magen so vriunt nach frivnden tvont ### von ir vater lande sach si manich man ### der kvnich friesch ovch div mere vor liebe er lachen hegan
###### 1655 | ### Nv wol mich miner vrovden so sprach Kriemhilt ### hie bringent mine mage vil manigen niwen schilt ### vnd halsperge wize swer nemen welle golt ### der denke miner leide vnd wil im immer wesen holt

<<< Übersicht <<< vorige Seite nächste Seite >>>